from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.joystick_configuration_angular import JoystickConfigurationAngular
from ..models.joystick_configuration_linear import JoystickConfigurationLinear

T = TypeVar("T", bound="JoystickConfiguration")


@attr.s(auto_attribs=True)
class JoystickConfiguration:
    """
    Attributes:
        linear (JoystickConfigurationLinear):
        angular (JoystickConfigurationAngular):
        scale (float):
        sensitivity (float):
    """

    linear: JoystickConfigurationLinear
    angular: JoystickConfigurationAngular
    scale: float
    sensitivity: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        linear = self.linear.value

        angular = self.angular.value

        scale = self.scale
        sensitivity = self.sensitivity

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "linear": linear,
                "angular": angular,
                "scale": scale,
                "sensitivity": sensitivity,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        linear = JoystickConfigurationLinear(d.pop("linear"))

        angular = JoystickConfigurationAngular(d.pop("angular"))

        scale = d.pop("scale")

        sensitivity = d.pop("sensitivity")

        joystick_configuration = cls(
            linear=linear,
            angular=angular,
            scale=scale,
            sensitivity=sensitivity,
        )

        joystick_configuration.additional_properties = d
        return joystick_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
